/*
  configuration_adv.h - Config file advance

  Part of DiyouPCBFirm
  Based on Marlin & Grbl

Copyright (c) 2013 V.Ayllon.  All rights reserved.

DiyouPCBFirm is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
to anyone for the consequences of using it or for whether it serves any
particular purpose or works at all, unless he says so in writing.  Refer
to the GNU General Public License, Version 2 or later, for full details.

Everyone is granted permission to copy, modify and redistribute
DiyouPCBFirm, but only under the conditions described in the GNU General Public
License.  A copy of this license is supposed to have been
given to you along with DiyouPCB so you can know your rights and
responsibilities.  It should be in a file named COPYING.  Among other
things, the copyright notice and this notice must be preserved on all
copies.

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*/
#ifndef CONFIGURATION_ADV_H
#define CONFIGURATION_ADV_H

//===========================================================================
//=============================Mechanical Settings===========================
//===========================================================================
#define X_HOME_POS X_MIN_POS
#define Y_HOME_POS Y_MIN_POS

//END AUTOSET LOCATIONS OF LIMIT SWITCHES -ZP

//homing hits the endstop, then retracts by this distance, before it tries to slowly bump again:
#define X_HOME_RETRACT_MM 2
#define Y_HOME_RETRACT_MM 2

//#define AXIS_RELATIVE_MODES {false, false}

#define MAX_STEP_FREQUENCY 40000 // Max step frequency for Ultimaker (5000 pps / half step)
//#define MAX_STEP_FREQUENCY 80000 // Max step frequency for Ultimaker (5000 pps / half step)
//By default pololu step drivers require an active high signal. However, some high power drivers require an active low signal as step.
#define INVERT_X_STEP_PIN false
#define INVERT_Y_STEP_PIN false

//#define DEFAULT_MINIMUMFEEDRATE       0.0     // minimum feedrate
//#define DEFAULT_MINTRAVELFEEDRATE     0.0

// minimum time in microseconds that a movement needs to take if the buffer is emptied.
#define DEFAULT_MINSEGMENTTIME        20000

// Minimum planner junction speed. Sets the default minimum speed the planner plans for at the end
// of the buffer and all stops. This should not be much greater than zero and should only be changed
// if unwanted behavior is observed on a user's machine when running at very slow speeds.
#define MINIMUM_PLANNER_SPEED 0.05// (mm/sec)

const unsigned int dropsegments=0; // 5 everything with less than this number of steps will be ignored as move and joined with the next movement

// Arc interpretation settings; see motion_control.cpp

#define SMALL_CIRCLE_RADIUS  2.5      // Small circles uses MM_PER_ARC_SEGMENT_SMALL segment size
     
#define MM_PER_ARC_SEGMENT_SMALL  .05 //.05
#define MM_PER_ARC_SEGMENT_LARGE  1
#define N_ARC_CORRECTION 25

//===========================================================================
//=============================Buffers           ============================
//===========================================================================

// The number of linear motions that can be in the plan at any give time.  
// THE BLOCK_BUFFER_SIZE NEEDS TO BE A POWER OF 2, i.g. 8,16,32 because shifts and ors are used to do the ringbuffering.

#define BLOCK_BUFFER_SIZE 16 // maximize block buffer

//The ASCII buffer for recieving from the serial:
#define MAX_CMD_SIZE 40 
#define BUFSIZE 4

#endif //__CONFIGURATION_ADV_H
